cmd

package
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Overview

Copyright © 2024 Achno <EMAIL ADDRESS>

Copyright © 2025 Achno <EMAIL ADDRESS>

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

Copyright © 2024 Achnologia <EMAIL ADDRESS>

Copyright © 2024 Achno <EMAIL ADDRESS>

Copyright © 2025 Achno <EMAIL ADDRESS>

Copyright © 2024 Achnologia <EMAIL ADDRESS>

Copyright © 2024 Achnologia <EMAIL ADDRESS>

Copyright © 2024 Achnologia <EMAIL ADDRESS>

Copyright © 2025 Achno <EMAIL ADDRESS>

Copyright © 2024 Achno <EMAIL ADDRESS>

Copyright © 2025 Achno <EMAIL ADDRESS>

Copyright © 2024 Achnologia <EMAIL ADDRESS>

Copyright © 2024 Achno <EMAIL ADDRESS>

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildBgCmd added in v0.2.4

func BuildBgCmd() *cobra.Command

func BuildBlendCmd added in v0.2.4

func BuildBlendCmd() *cobra.Command

Blend Command

func BuildBorderCmd added in v0.2.4

func BuildBorderCmd() *cobra.Command

Border Command

func BuildBrightnessCmd added in v0.2.4

func BuildBrightnessCmd() *cobra.Command

Brightness Command

func BuildClrConvertCmd added in v0.2.4

func BuildClrConvertCmd() *cobra.Command

Convert Command

func BuildColorCmd added in v0.2.4

func BuildColorCmd() *cobra.Command

func BuildCompressCmd added in v0.2.2

func BuildCompressCmd() *cobra.Command

func BuildContrastCmd added in v0.2.4

func BuildContrastCmd() *cobra.Command

Contrast Command

func BuildConvertCmd added in v0.2.4

func BuildConvertCmd() *cobra.Command

func BuildDarkCmd added in v0.2.4

func BuildDarkCmd() *cobra.Command

Dark Command

func BuildDrawCmd added in v0.2.4

func BuildDrawCmd() *cobra.Command

func BuildEffectsCmd added in v0.2.4

func BuildEffectsCmd() *cobra.Command

func BuildExtractCmd added in v0.2.4

func BuildExtractCmd() *cobra.Command

func BuildFlipCmd added in v0.2.4

func BuildFlipCmd() *cobra.Command

Flip Command

func BuildGammaCmd added in v0.2.4

func BuildGammaCmd() *cobra.Command

Gamma Command

func BuildGifCmd added in v0.2.4

func BuildGifCmd() *cobra.Command

func BuildGradientCmd added in v0.2.4

func BuildGradientCmd() *cobra.Command

Gradient Command

func BuildGrayscaleCmd added in v0.2.4

func BuildGrayscaleCmd() *cobra.Command

Grayscale Command

func BuildGridCmd added in v0.2.4

func BuildGridCmd() *cobra.Command

func BuildInvertCmd added in v0.2.4

func BuildInvertCmd() *cobra.Command

func BuildLightCmd added in v0.2.4

func BuildLightCmd() *cobra.Command

Light Command

func BuildListCmd added in v0.2.4

func BuildListCmd() *cobra.Command

func BuildMirrorCmd added in v0.2.4

func BuildMirrorCmd() *cobra.Command

Mirror Command

func BuildOCRCmd added in v0.2.2

func BuildOCRCmd() *cobra.Command

func BuildPixelateCmd added in v0.2.4

func BuildPixelateCmd() *cobra.Command

func BuildResizeCmd added in v0.2.4

func BuildResizeCmd() *cobra.Command

func BuildRoundCmd added in v0.2.4

func BuildRoundCmd() *cobra.Command

func BuildSaturationCmd added in v0.2.4

func BuildSaturationCmd() *cobra.Command

Saturation Command

func BuildStackCmd added in v0.2.4

func BuildStackCmd() *cobra.Command

func BuildTiltCmd added in v0.2.4

func BuildTiltCmd() *cobra.Command

func BuildUpscaleCmd added in v0.2.4

func BuildUpscaleCmd() *cobra.Command

func BuildVariantsCmd added in v0.2.4

func BuildVariantsCmd() *cobra.Command

Variants Command

func BuildWheelCmd added in v0.2.4

func BuildWheelCmd() *cobra.Command

Wheel Command

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func GetWheelMap added in v0.2.4

func GetWheelMap() map[string]func(string) ([]string, error)

func GetvariationMap added in v0.2.4

func GetvariationMap() map[string]func(string, int) ([]string, error)

func LoadOCRConfig added in v0.2.2

func LoadOCRConfig(cmd *cobra.Command) (providers.Config, error)

(1) Loads default config (2) Merges the schema file if the schema flag is set and overrides the fields that are set (3) Overwrites the config with the flags if they are set

func RunBgCmd added in v0.2.4

func RunBgCmd(cmd *cobra.Command, args []string)

func RunBlendCmd added in v0.2.4

func RunBlendCmd(cmd *cobra.Command, args []string)

func RunBorderCmd added in v0.2.4

func RunBorderCmd(cmd *cobra.Command, args []string)

func RunBrightnessCmd added in v0.2.4

func RunBrightnessCmd(cmd *cobra.Command, args []string)

func RunClrConvertCmd added in v0.2.4

func RunClrConvertCmd(cmd *cobra.Command, args []string)

func RunCompressCmd added in v0.2.2

func RunCompressCmd(cmd *cobra.Command, args []string)

func RunContrastCmd added in v0.2.4

func RunContrastCmd(cmd *cobra.Command, args []string)

func RunConvertCmd added in v0.2.4

func RunConvertCmd(cmd *cobra.Command, args []string)

func RunDarkCmd added in v0.2.4

func RunDarkCmd(cmd *cobra.Command, args []string)

func RunExtractCmd added in v0.2.4

func RunExtractCmd(cmd *cobra.Command, args []string)

func RunFlipCmd added in v0.2.4

func RunFlipCmd(cmd *cobra.Command, args []string)

func RunGammaCmd added in v0.2.4

func RunGammaCmd(cmd *cobra.Command, args []string)

func RunGifCmd added in v0.2.4

func RunGifCmd(cmd *cobra.Command, args []string)

func RunGradientCmd added in v0.2.4

func RunGradientCmd(cmd *cobra.Command, args []string)

func RunGrayscaleCmd added in v0.2.4

func RunGrayscaleCmd(cmd *cobra.Command, args []string)

func RunGridCmd added in v0.2.4

func RunGridCmd(cmd *cobra.Command, args []string)

func RunInvertCmd added in v0.2.4

func RunInvertCmd(cmd *cobra.Command, args []string)

func RunLightCmd added in v0.2.4

func RunLightCmd(cmd *cobra.Command, args []string)

func RunListCmd added in v0.2.4

func RunListCmd(cmd *cobra.Command, args []string)

func RunMirrorCmd added in v0.2.4

func RunMirrorCmd(cmd *cobra.Command, args []string)

func RunPixelateCmd added in v0.2.4

func RunPixelateCmd(cmd *cobra.Command, args []string)

func RunResizeCmd added in v0.2.4

func RunResizeCmd(cmd *cobra.Command, args []string)

func RunRoundCmd added in v0.2.4

func RunRoundCmd(cmd *cobra.Command, args []string)

func RunSaturationCmd added in v0.2.4

func RunSaturationCmd(cmd *cobra.Command, args []string)

func RunStackCmd added in v0.2.4

func RunStackCmd(cmd *cobra.Command, args []string)

func RunTiltCmd added in v0.2.4

func RunTiltCmd(cmd *cobra.Command, args []string)

func RunUpscaleCmd added in v0.2.4

func RunUpscaleCmd(cmd *cobra.Command, args []string)

func RunVariantsCmd added in v0.2.4

func RunVariantsCmd(cmd *cobra.Command, args []string)

func RunWheelCmd added in v0.2.4

func RunWheelCmd(cmd *cobra.Command, args []string)

func ValidateParseBgCmd added in v0.2.4

func ValidateParseBgCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseBlendCmd added in v0.2.4

func ValidateParseBlendCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseBorderCmd added in v0.2.4

func ValidateParseBorderCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseBrightnessCmd added in v0.2.4

func ValidateParseBrightnessCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseClrConvertCmd added in v0.2.4

func ValidateParseClrConvertCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseCompressCmd added in v0.2.4

func ValidateParseCompressCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseContrastCmd added in v0.2.4

func ValidateParseContrastCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseConvertCmd added in v0.2.4

func ValidateParseConvertCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseDarkCmd added in v0.2.4

func ValidateParseDarkCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseExtractCmd added in v0.2.4

func ValidateParseExtractCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseFlipCmd added in v0.2.4

func ValidateParseFlipCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseGammaCmd added in v0.2.4

func ValidateParseGammaCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseGifCmd added in v0.2.4

func ValidateParseGifCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseGradientCmd added in v0.2.4

func ValidateParseGradientCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseGrayscaleCmd added in v0.2.4

func ValidateParseGrayscaleCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseGridCmd added in v0.2.4

func ValidateParseGridCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseInvertCmd added in v0.2.4

func ValidateParseInvertCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseLightCmd added in v0.2.4

func ValidateParseLightCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseMirrorCmd added in v0.2.4

func ValidateParseMirrorCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseOCRCmd added in v0.2.4

func ValidateParseOCRCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParsePixelateCmd added in v0.2.4

func ValidateParsePixelateCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseResizeCmd added in v0.2.4

func ValidateParseResizeCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseRoundCmd added in v0.2.4

func ValidateParseRoundCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseSaturationCmd added in v0.2.4

func ValidateParseSaturationCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseStackCmd added in v0.2.4

func ValidateParseStackCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseTiltCmd added in v0.2.4

func ValidateParseTiltCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseUpscaleCmd added in v0.2.4

func ValidateParseUpscaleCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseVariantsCmd added in v0.2.4

func ValidateParseVariantsCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

func ValidateParseWheelCmd added in v0.2.4

func ValidateParseWheelCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error

Types

type GlobalFlagBuilder added in v0.2.4

type GlobalFlagBuilder struct {
	// contains filtered or unexported fields
}

GlobalFlagBuilder provides a fluent API for adding flags to a cobra command.

func (*GlobalFlagBuilder) WithBatch added in v0.2.4

func (f *GlobalFlagBuilder) WithBatch() *GlobalFlagBuilder

WithBatch adds the --batch flag for batch processing individual files.

func (*GlobalFlagBuilder) WithDir added in v0.2.4

func (f *GlobalFlagBuilder) WithDir() *GlobalFlagBuilder

WithDir adds the --dir flag for batch processing an entire directory.

func (*GlobalFlagBuilder) WithOutput added in v0.2.4

func (f *GlobalFlagBuilder) WithOutput() *GlobalFlagBuilder

WithOutput adds the --output flag to specify the output destination.

func (*GlobalFlagBuilder) WithPreview added in v0.2.4

func (f *GlobalFlagBuilder) WithPreview() *GlobalFlagBuilder

WithPreview adds the --preview flag to enable or disable image previewing.

func (*GlobalFlagBuilder) WithYes added in v0.2.4

func (f *GlobalFlagBuilder) WithYes() *GlobalFlagBuilder

WithYes adds the --yes flag to auto-accept confirmation prompts.

Jump to