Documentation
¶
Overview ¶
Copyright © 2024 Achno <EMAIL ADDRESS>
Copyright © 2025 Achno <EMAIL ADDRESS>
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Copyright © 2024 Achnologia <EMAIL ADDRESS>
Copyright © 2024 Achno <EMAIL ADDRESS>
Copyright © 2025 Achno <EMAIL ADDRESS>
Copyright © 2024 Achnologia <EMAIL ADDRESS>
Copyright © 2025 Achno ¶
Copyright © 2024 Achnologia <EMAIL ADDRESS>
Copyright © 2024 Achnologia <EMAIL ADDRESS>
Copyright © 2025 Achno <EMAIL ADDRESS>
Copyright © 2024 Achno <EMAIL ADDRESS>
Copyright © 2025 Achno <EMAIL ADDRESS>
Copyright © 2024 Achnologia <EMAIL ADDRESS>
Copyright © 2026 Achno ¶
Copyright © 2024 Achno <EMAIL ADDRESS>
Index ¶
- func BuildBgCmd() *cobra.Command
- func BuildBlendCmd() *cobra.Command
- func BuildBorderCmd() *cobra.Command
- func BuildBrightnessCmd() *cobra.Command
- func BuildClrConvertCmd() *cobra.Command
- func BuildColorCmd() *cobra.Command
- func BuildCompressCmd() *cobra.Command
- func BuildContrastCmd() *cobra.Command
- func BuildConvertCmd() *cobra.Command
- func BuildDarkCmd() *cobra.Command
- func BuildDrawCmd() *cobra.Command
- func BuildEffectsCmd() *cobra.Command
- func BuildExtractCmd() *cobra.Command
- func BuildFlipCmd() *cobra.Command
- func BuildGammaCmd() *cobra.Command
- func BuildGifCmd() *cobra.Command
- func BuildGradientCmd() *cobra.Command
- func BuildGrayscaleCmd() *cobra.Command
- func BuildGridCmd() *cobra.Command
- func BuildInvertCmd() *cobra.Command
- func BuildLightCmd() *cobra.Command
- func BuildListCmd() *cobra.Command
- func BuildMirrorCmd() *cobra.Command
- func BuildOCRCmd() *cobra.Command
- func BuildPixelateCmd() *cobra.Command
- func BuildResizeCmd() *cobra.Command
- func BuildRoundCmd() *cobra.Command
- func BuildSaturationCmd() *cobra.Command
- func BuildStackCmd() *cobra.Command
- func BuildTiltCmd() *cobra.Command
- func BuildUpscaleCmd() *cobra.Command
- func BuildVariantsCmd() *cobra.Command
- func BuildWheelCmd() *cobra.Command
- func Execute()
- func GetWheelMap() map[string]func(string) ([]string, error)
- func GetvariationMap() map[string]func(string, int) ([]string, error)
- func LoadOCRConfig(cmd *cobra.Command) (providers.Config, error)
- func RunBgCmd(cmd *cobra.Command, args []string)
- func RunBlendCmd(cmd *cobra.Command, args []string)
- func RunBorderCmd(cmd *cobra.Command, args []string)
- func RunBrightnessCmd(cmd *cobra.Command, args []string)
- func RunClrConvertCmd(cmd *cobra.Command, args []string)
- func RunCompressCmd(cmd *cobra.Command, args []string)
- func RunContrastCmd(cmd *cobra.Command, args []string)
- func RunConvertCmd(cmd *cobra.Command, args []string)
- func RunDarkCmd(cmd *cobra.Command, args []string)
- func RunExtractCmd(cmd *cobra.Command, args []string)
- func RunFlipCmd(cmd *cobra.Command, args []string)
- func RunGammaCmd(cmd *cobra.Command, args []string)
- func RunGifCmd(cmd *cobra.Command, args []string)
- func RunGradientCmd(cmd *cobra.Command, args []string)
- func RunGrayscaleCmd(cmd *cobra.Command, args []string)
- func RunGridCmd(cmd *cobra.Command, args []string)
- func RunInvertCmd(cmd *cobra.Command, args []string)
- func RunLightCmd(cmd *cobra.Command, args []string)
- func RunListCmd(cmd *cobra.Command, args []string)
- func RunMirrorCmd(cmd *cobra.Command, args []string)
- func RunPixelateCmd(cmd *cobra.Command, args []string)
- func RunResizeCmd(cmd *cobra.Command, args []string)
- func RunRoundCmd(cmd *cobra.Command, args []string)
- func RunSaturationCmd(cmd *cobra.Command, args []string)
- func RunStackCmd(cmd *cobra.Command, args []string)
- func RunTiltCmd(cmd *cobra.Command, args []string)
- func RunUpscaleCmd(cmd *cobra.Command, args []string)
- func RunVariantsCmd(cmd *cobra.Command, args []string)
- func RunWheelCmd(cmd *cobra.Command, args []string)
- func ValidateParseBgCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseBlendCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseBorderCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseBrightnessCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseClrConvertCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseCompressCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseContrastCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseConvertCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseDarkCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseExtractCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseFlipCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseGammaCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseGifCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseGradientCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseGrayscaleCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseGridCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseInvertCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseLightCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseMirrorCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseOCRCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParsePixelateCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseResizeCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseRoundCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseSaturationCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseStackCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseTiltCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseUpscaleCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseVariantsCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- func ValidateParseWheelCmd(cmd *cobra.Command, flags config.GlobalSubCommandFlags, args []string) error
- type GlobalFlagBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildBgCmd ¶ added in v0.2.4
func BuildBrightnessCmd ¶ added in v0.2.4
Brightness Command
func BuildColorCmd ¶ added in v0.2.4
func BuildCompressCmd ¶ added in v0.2.2
func BuildConvertCmd ¶ added in v0.2.4
func BuildDrawCmd ¶ added in v0.2.4
func BuildEffectsCmd ¶ added in v0.2.4
func BuildExtractCmd ¶ added in v0.2.4
func BuildGifCmd ¶ added in v0.2.4
func BuildGridCmd ¶ added in v0.2.4
func BuildInvertCmd ¶ added in v0.2.4
func BuildListCmd ¶ added in v0.2.4
func BuildOCRCmd ¶ added in v0.2.2
func BuildPixelateCmd ¶ added in v0.2.4
func BuildResizeCmd ¶ added in v0.2.4
func BuildRoundCmd ¶ added in v0.2.4
func BuildSaturationCmd ¶ added in v0.2.4
Saturation Command
func BuildStackCmd ¶ added in v0.2.4
func BuildTiltCmd ¶ added in v0.2.4
func BuildUpscaleCmd ¶ added in v0.2.4
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func GetvariationMap ¶ added in v0.2.4
func LoadOCRConfig ¶ added in v0.2.2
(1) Loads default config (2) Merges the schema file if the schema flag is set and overrides the fields that are set (3) Overwrites the config with the flags if they are set
func RunBlendCmd ¶ added in v0.2.4
func RunBorderCmd ¶ added in v0.2.4
func RunBrightnessCmd ¶ added in v0.2.4
func RunClrConvertCmd ¶ added in v0.2.4
func RunCompressCmd ¶ added in v0.2.2
func RunContrastCmd ¶ added in v0.2.4
func RunConvertCmd ¶ added in v0.2.4
func RunDarkCmd ¶ added in v0.2.4
func RunExtractCmd ¶ added in v0.2.4
func RunFlipCmd ¶ added in v0.2.4
func RunGammaCmd ¶ added in v0.2.4
func RunGradientCmd ¶ added in v0.2.4
func RunGrayscaleCmd ¶ added in v0.2.4
func RunGridCmd ¶ added in v0.2.4
func RunInvertCmd ¶ added in v0.2.4
func RunLightCmd ¶ added in v0.2.4
func RunListCmd ¶ added in v0.2.4
func RunMirrorCmd ¶ added in v0.2.4
func RunPixelateCmd ¶ added in v0.2.4
func RunResizeCmd ¶ added in v0.2.4
func RunRoundCmd ¶ added in v0.2.4
func RunSaturationCmd ¶ added in v0.2.4
func RunStackCmd ¶ added in v0.2.4
func RunTiltCmd ¶ added in v0.2.4
func RunUpscaleCmd ¶ added in v0.2.4
func RunVariantsCmd ¶ added in v0.2.4
func RunWheelCmd ¶ added in v0.2.4
func ValidateParseBgCmd ¶ added in v0.2.4
func ValidateParseBlendCmd ¶ added in v0.2.4
func ValidateParseBorderCmd ¶ added in v0.2.4
func ValidateParseBrightnessCmd ¶ added in v0.2.4
func ValidateParseClrConvertCmd ¶ added in v0.2.4
func ValidateParseCompressCmd ¶ added in v0.2.4
func ValidateParseContrastCmd ¶ added in v0.2.4
func ValidateParseConvertCmd ¶ added in v0.2.4
func ValidateParseDarkCmd ¶ added in v0.2.4
func ValidateParseExtractCmd ¶ added in v0.2.4
func ValidateParseFlipCmd ¶ added in v0.2.4
func ValidateParseGammaCmd ¶ added in v0.2.4
func ValidateParseGifCmd ¶ added in v0.2.4
func ValidateParseGradientCmd ¶ added in v0.2.4
func ValidateParseGrayscaleCmd ¶ added in v0.2.4
func ValidateParseGridCmd ¶ added in v0.2.4
func ValidateParseInvertCmd ¶ added in v0.2.4
func ValidateParseLightCmd ¶ added in v0.2.4
func ValidateParseMirrorCmd ¶ added in v0.2.4
func ValidateParseOCRCmd ¶ added in v0.2.4
func ValidateParsePixelateCmd ¶ added in v0.2.4
func ValidateParseResizeCmd ¶ added in v0.2.4
func ValidateParseRoundCmd ¶ added in v0.2.4
func ValidateParseSaturationCmd ¶ added in v0.2.4
func ValidateParseStackCmd ¶ added in v0.2.4
func ValidateParseTiltCmd ¶ added in v0.2.4
func ValidateParseUpscaleCmd ¶ added in v0.2.4
func ValidateParseVariantsCmd ¶ added in v0.2.4
func ValidateParseWheelCmd ¶ added in v0.2.4
Types ¶
type GlobalFlagBuilder ¶ added in v0.2.4
type GlobalFlagBuilder struct {
// contains filtered or unexported fields
}
GlobalFlagBuilder provides a fluent API for adding flags to a cobra command.
func (*GlobalFlagBuilder) WithBatch ¶ added in v0.2.4
func (f *GlobalFlagBuilder) WithBatch() *GlobalFlagBuilder
WithBatch adds the --batch flag for batch processing individual files.
func (*GlobalFlagBuilder) WithDir ¶ added in v0.2.4
func (f *GlobalFlagBuilder) WithDir() *GlobalFlagBuilder
WithDir adds the --dir flag for batch processing an entire directory.
func (*GlobalFlagBuilder) WithOutput ¶ added in v0.2.4
func (f *GlobalFlagBuilder) WithOutput() *GlobalFlagBuilder
WithOutput adds the --output flag to specify the output destination.
func (*GlobalFlagBuilder) WithPreview ¶ added in v0.2.4
func (f *GlobalFlagBuilder) WithPreview() *GlobalFlagBuilder
WithPreview adds the --preview flag to enable or disable image previewing.
func (*GlobalFlagBuilder) WithYes ¶ added in v0.2.4
func (f *GlobalFlagBuilder) WithYes() *GlobalFlagBuilder
WithYes adds the --yes flag to auto-accept confirmation prompts.